@@ -1,5 +1,5 @@
 # robster/perceptron.py SingleLayerPerceptron
-from robster.model import LinearModel
+from robster.model.linear_model import LinearModel
 
 class SingleLayerPerceptron:
   def __init__(self, epochs, mini_batch, learning_rate = 3e-3, report = 1, MODEL = LinearModel):
